#include <phyphoxBle.h>

//DS18B20
#include <OneWire.h>
#include <DallasTemperature.h>
#define ONE_WIRE_BUS 5
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature sensors(&oneWire);
DeviceAddress Gr = { 0x28, 0x99, 0xC9, 0x07, 0xD6, 0x01, 0x3C, 0x7F };
DeviceAddress Wi = { 0x28, 0x4B, 0x18, 0x07, 0xD6, 0x01, 0x3C, 0x46 };
DeviceAddress Ro = { 0x28, 0xCF, 0xC4, 0x07, 0xD6, 0x01, 0x3C, 0x0F };

void setup()
{
  Serial.begin(115200);
  //PHYPHOX init
  PhyphoxBLE::start("CVTemp");

  //Experiment
  PhyphoxBleExperiment CVWaterTemp;
  CVWaterTemp.setTitle("CVWaterTemp");
  CVWaterTemp.setCategory("ESP32_DB18");
  CVWaterTemp.setDescription("temp als f(t)");

  //View
  PhyphoxBleExperiment::View CVTemp;
  CVTemp.setLabel("CVTemp");

  //Graph
  PhyphoxBleExperiment::Graph Groen;
  Groen.setLabel("   Groen f(t)");
  Groen.setUnitX("uur.min");
  Groen.setUnitY("[°C]");
  Groen.setLabelX("Tijd");
  Groen.setLabelY("Groen");
  Groen.setColor("23FF00"); //Groen
  Groen.setChannel(1, 2);

  PhyphoxBleExperiment::Graph Wit;
  Wit.setLabel("   Wit f(t)");
  Wit.setUnitX("uur.min");
  Wit.setUnitY("[°C]");
  Wit.setLabelX("Tijd");
  Wit.setLabelY("Wit");
  Wit.setColor("FFFFFF"); //Wit
  Wit.setChannel(1, 3);

  PhyphoxBleExperiment::Graph Rood;
  Rood.setLabel("   Rood f(t)");
  Rood.setUnitX("uur.min");
  Rood.setUnitY("[°C]");
  Rood.setLabelX("Tijd");
  Rood.setLabelY("Rood");
  Rood.setColor("FF0000"); //Rood
  Rood.setChannel(1, 4);
 
  //attach to experiment
  CVTemp.addElement(Groen);             //attach First graph to view
  CVTemp.addElement(Wit);             //attach SecondT graph to view
  CVTemp.addElement(Rood);             //attach Third graph to view

  //attach value to view
  CVWaterTemp.addView(CVTemp);          //attach view to experiment
  PhyphoxBLE::addExperiment(CVWaterTemp);  //attach experiment to server

  //Sensors
  sensors.begin();
  sensors.setResolution(Gr, 12);
  sensors.setResolution(Wi, 12);
  sensors.setResolution(Ro, 12);
  
}

void loop()
{	
  float t = (float)millis() / 60000;
  sensors.requestTemperatures(); // Send the command to get temperatures
  float Green = sensors.getTempC(Gr);
  float White = sensors.getTempC(Wi);
  float Red = sensors.getTempC(Ro);
  Serial.print(Green); Serial.print(","); Serial.print(White); Serial.print(","); Serial.println(Red);

  PhyphoxBLE::write(t, Green, White, Red);

  delay(5000);
}
